@@ -21,19 +21,22 @@ class Geometry(object):
  def __init__(self,**argv):
 
   if comm.rank == 0:
-   if argv.setdefault('user',False):
+   if argv.setdefault('only_geo',False):
+     Mesher(argv) #this create mesh.msh
+   else:    
+    if argv.setdefault('user',False):
      self.import_mesh(**argv)
      argv.update({'centroids':self.elem_centroids})
      self.elem_mat_map = argv['correlation'](**argv)
-   else:
+    else:
      Mesher(argv) #this create mesh.msh
      self.dmin = argv['dmin']
      self.import_mesh(**argv)
      self.elem_mat_map = np.zeros(len(self.elems)) #omhogeneous material
-   self.update_side_interface()
-   self.data = self.compute_mesh_data(**argv)
-   if argv.setdefault('save',True):
-    np.savez_compressed('geometry',self.data)   
+    self.update_side_interface()
+    self.data = self.compute_mesh_data(**argv)
+    if argv.setdefault('save',True):
+     save_data('geometry',self.data)   
 
 
  def compute_boundary_connection(self):
@@ -105,6 +108,13 @@ class Geometry(object):
             e.append(-1)
             self.elem_side_map[n].append(-1)
 
+    if self.direction=='x':
+       dirr = 0
+    elif self.direction=='y':
+       dirr = 1
+    else:
+       dirr = 2
+       
 
 
     return {
@@ -151,7 +161,8 @@ class Geometry(object):
           'n_non_boundary_side_per_elem': np.array(self.n_non_boundary_side_per_elem,dtype=np.int),
           'pp':np.array(self.pp),\
           'side_per_elem':np.array(self.side_per_elem),\
-          'meta':np.asarray([self.n_elems,self.kappa_factor,self.dim,len(self.nodes),len(self.side_list['active'])],np.float64)}
+          'applied_gradient':np.array(self.applied_grad),\
+          'meta':np.asarray([self.n_elems,self.kappa_factor,self.dim,len(self.nodes),len(self.side_list['active']),dirr],np.float64)}
 
 
 
@@ -197,10 +208,9 @@ class Geometry(object):
       self.intj.append(l1)   
       self.intk.append(normal*area/vol1)
       self.intk.append(-normal*area/vol2)
-      #ij.append([l1,l2])
-      #ij.append([l2,l1])
 
-     if not l1 == l2 :#and not (ll in self.side_list['Interface']):
+     if not (l1 == l2) and  (not (ll in self.side_list['Interface'])):
+     #if not (l1 == l2):
        self.i.append(l1)   
        self.j.append(l2)   
        self.i.append(l2)   
@@ -210,17 +220,17 @@ class Geometry(object):
        self.k.append(normal*area/vol1)
        self.k.append(-normal*area/vol2)
      else:
-       self.eb.append(l1)
-       self.sb.append(ll)
-       self.db.append(normal*area/vol1)
+
+       if ll in self.side_list['Boundary']:
+        self.eb.append(l1)
+        self.sb.append(ll)
+        self.db.append(normal*area/vol1)
    
+
    self.k = np.array(self.k).T
    self.db = np.array(self.db).T
    self.intk = np.array(self.intk).T
-
    
-   #self.i += self.inti
-   #self.j += self.intj
    self.ij = ij
 
 
@@ -529,15 +539,15 @@ class Geometry(object):
 
  def compute_boundary_condition_data(self,argv):
 
-    direction = argv.setdefault('direction','x')
-    if direction == 'x':
+    self.direction = argv.setdefault('direction','x')
+    if self.direction == 'x':
      gradir = 0
-     applied_grad = [1,0,0]
-    if direction == 'y': 
-     applied_grad = [0,1,0]
+     self.applied_grad = [1,0,0]
+    if self.direction == 'y':
      gradir = 1
-    if direction == 'z':
-     applied_grad = [0,0,1]
+     self.applied_grad = [0,1,0]
+    if self.direction == 'z':
+     self.applied_grad = [0,0,1]
      gradir = 2
 
     if gradir == 0:
@@ -580,6 +590,7 @@ class Geometry(object):
     B_with_area_old = sp.dok_matrix((n_el,n_el),dtype=np.float64)
     self.B_area = np.zeros(n_el,dtype=np.float64)
    
+    counter = 0
     self.pp = ()
     self.ip = []; self.jp = []; self.dp = []; self.pv = [] 
     if len(self.side_list.setdefault('Periodic',[])) > 0:
@@ -610,15 +621,17 @@ class Geometry(object):
       if abs(side_value[side[0]]) > 0:
        self.pp += ((self.ij.index([i,j]),side_value[side[0]]),)
        self.ip.append(i); self.jp.append(j); self.dp.append(side_value[side[0]]); self.pv.append(normal*area/voli)
+       counter +=1
 
       if abs(side_value[side[1]]) > 0:
        self.pp += ((self.ij.index([j,i]),side_value[side[1]]),)
-       #self.pp.append(self.ij.index([j,i]))
        self.ip.append(j); self.jp.append(i); self.dp.append(side_value[side[1]]); self.pv.append(-normal*area/volj)
+       counter +=1
 
-      if np.linalg.norm(np.cross(self.face_normals[side[0]],applied_grad)) < 1e-12:
+      if np.linalg.norm(np.cross(self.face_normals[side[0]],self.applied_grad)) < 1e-12:
        B_with_area_old[i,j] = abs(side_value[side[0]]*area)
-      
+    
+
     #select flux sides-------------------------------
     self.flux_sides = [] #where flux goes
     total_area = 0
@@ -650,7 +663,7 @@ class Geometry(object):
     self.B_with_area_old = B_with_area_old.tocoo()
     self.pv = np.array(self.pv).T
     self.kappa_factor = self.size[gradir]/area_flux
-  
+
  def compute_least_square_weigths(self):
 
    nd = len(self.elems[0])
