@@ -402,15 +402,15 @@ class Mesher(object):
     self.create_loop(loops,line_list,store)
 
     #Create internal loops-------------
+    a = 0
     for interior in region.interiors:
-
+     a +=1
      pp = list(interior.coords)[:-1]
      line_list = self.create_line_list(pp,points,lines,store)
      loops +=1
      local_loops.append(loops)
      self.create_loop(loops,line_list,store)
     #---------------------------------
-
     ss +=1
     bulk_surface.append(ss)
     self.create_surface_old(local_loops,ss,store)
@@ -490,7 +490,8 @@ class Mesher(object):
     pore_wall.append(l+1)
 
   additional_boundary = []
-  if argv.setdefault('Periodic',[True,True,True])[0]:
+  argv.setdefault('Periodic',[True,True,True])
+  if argv['Periodic'][0]:
    strc = r'''Physical Line('Periodic_2') = {'''
    for n in range(len(hot)-1):
     strc += str(hot[n]) + ','
@@ -509,13 +510,13 @@ class Mesher(object):
     additional_boundary.append(k)
 
   if argv.setdefault('Periodic',[True,True,True])[1] and len(upper) > 0:
-   strc = r'''Physical Line('Periodic_4') = {'''
+   strc = r'''Physical Line('Periodic_3') = {'''
    for n in range(len(upper)-1):
     strc += str(upper[n]) + ','
    strc += str(upper[-1]) + '};\n'
    store.write(strc)
 
-   strc = r'''Physical Line('Periodic_3') = {'''
+   strc = r'''Physical Line('Periodic_4') = {'''
    for n in range(len(lower)-1):
     strc += str(lower[n]) + ','
    strc += str(lower[-1]) + '};\n'
@@ -556,16 +557,17 @@ class Mesher(object):
     else :
      strc += ','
 
-  for n in range(len(hot)):
-   periodic = self.FindPeriodic(hot[n],cold,points,lines)
-   
-   strc = 'Periodic Line{' + str(hot[n]) + '}={' + str(periodic) + '};\n'
-   store.write(strc)
+  if argv['Periodic'][0]:
+   for n in range(len(hot)):
+    periodic = self.FindPeriodic(hot[n],cold,points,lines) 
+    strc = 'Periodic Line{' + str(hot[n]) + '}={' + str(periodic) + '};\n'
+    store.write(strc)
 
-  for n in range(len(lower)):
-   periodic = self.FindPeriodic(lower[n],upper,points,lines)
-   strc = 'Periodic Line{' + str(lower[n]) + '}={' + str(periodic) + '};\n'
-   store.write(strc)
+  if argv['Periodic'][1]:
+   for n in range(len(lower)):
+    periodic = self.FindPeriodic(lower[n],upper,points,lines)
+    strc = 'Periodic Line{' + str(lower[n]) + '}={' + str(periodic) + '};\n'
+    store.write(strc)
 
 #-------------------------------------------------------
   store.close()
